@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Settings
- * @version    $Id: 160.nameserver.php 138 2010-01-27 08:54:31Z Dessa $
+ * @version    $Id: 160.nameserver.php 829 2010-04-20 06:22:11Z d00p $
  */
 
 return array(
@@ -59,6 +59,16 @@ return array(
 					'default' => '',
 					'save_method' => 'storeSettingField',
 					),
+				'system_defaultttl' => array(
+					'label' => $lng['serversettings']['defaultttl'],
+					'settinggroup' => 'system',
+					'varname' => 'defaultttl',
+					'type' => 'int',
+					'default' => 604800, /* 1 week */
+					'int_min' => 86400, /* 1 day */
+					'int_max' => 2147483647, /* integer max */
+					'save_method' => 'storeSettingField',
+					),
 				),
 			),
 		),
