@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Settings
- * @version    $Id: 190.ticket.php 779 2010-04-13 05:41:09Z d00p $
+ * @version    $Id: 190.ticket.php 854 2010-04-29 05:38:32Z d00p $
  */
 
 return array(
@@ -125,6 +125,16 @@ return array(
 					'type' => 'hidden',
 					'default' => '',
 					),
+				'ticket_default_priority' => array(
+					'label' => $lng['serversettings']['ticket']['default_priority'],
+					'settinggroup' => 'ticket',
+					'varname' => 'default_priority',
+					'type' => 'option',
+					'default' => 2,
+					'option_mode' => 'one',
+					'option_options' => array(1 => $lng['ticket']['unf_high'], 2 => $lng['ticket']['unf_normal'], 3 => $lng['ticket']['unf_low']),
+					'save_method' => 'storeSettingField', 
+					),
 				),
 			),
 		)
