@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Panel
- * @version    $Id: admin_configfiles.php 547 2010-03-08 15:04:05Z d00p $
+ * @version    $Id: admin_configfiles.php 663 2010-03-22 12:36:59Z d00p $
  */
 
 define('AREA', 'admin');
@@ -95,10 +95,9 @@ if($userinfo['change_serversettings'] == '1')
 			'<VIRTUAL_MAILBOX_BASE>' => $settings['system']['vmail_homedir'],
 			'<VIRTUAL_UID_MAPS>' => $settings['system']['vmail_uid'],
 			'<VIRTUAL_GID_MAPS>' => $settings['system']['vmail_gid'],
-			'<AWSTATS_PATH>' => $settings['system']['awstats_path'],
 			'<SSLPROTOCOLS>' => ($settings['system']['use_ssl'] == '1') ? 'imaps pop3s' : '',
 			'<REALTIME_PORT>' => $settings['system']['realtime_port'],
-			'<CUSTOMER_TMP>' => ($settings['system']['mod_fcgid_tmpdir'] != '') ? $settings['system']['mod_fcgid_tmpdir'] : '/tmp/'
+			'<CUSTOMER_TMP>' => ($settings['system']['mod_fcgid_tmpdir'] != '') ? makeCorrectDir($settings['system']['mod_fcgid_tmpdir']) : '/tmp/'
 		);
 		$files = '';
 		$configpage = '';
@@ -111,6 +110,7 @@ if($userinfo['change_serversettings'] == '1')
 				if(is_array($value))
 				{
 					$commands = implode("\n", $value);
+					$commands = str_replace("\n\n", "\n", $commands);
 
 					if($commands != '')
 					{
