@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Panel
- * @version    $Id: customer_email.php 731 2010-04-07 06:57:27Z d00p $
+ * @version    $Id: customer_email.php 882 2010-05-04 06:43:23Z d00p $
  */
 
 define('AREA', 'customer');
@@ -139,8 +139,10 @@ elseif($page == 'emails')
 			}
 		}
 
-		$emaildomains_count = $db->query_first("SELECT COUNT(`id`) AS `count` FROM `" . TABLE_PANEL_DOMAINS . "` WHERE `customerid`='" . $userinfo['customerid'] . "' AND `isemaildomain`='1' ORDER BY `domain` ASC");
+		$emaildomains_count = $db->query_first("SELECT COUNT(`id`) AS `count` FROM `" . TABLE_PANEL_DOMAINS . "` WHERE `customerid`='" . (int)$userinfo['customerid'] . "' AND `isemaildomain`='1' ORDER BY `domain` ASC");
 		$emaildomains_count = $emaildomains_count['count'];
+
+		$emailscount = $db->num_rows($result);
 		eval("echo \"" . getTemplate("email/emails") . "\";");
 	}
 	elseif($action == 'delete'
