@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Install
- * @version    $Id: install.php 868 2010-05-03 11:40:48Z EleRas $
+ * @version    $Id: install.php 921 2010-05-07 14:25:08Z EleRas $
  */
 
 /**
@@ -659,7 +659,8 @@ if(isset($_POST['installstep'])
 			 `port` = '80',
 			 `namevirtualhost_statement` = '1',
 			 `vhostcontainer` = '1', 
-			 `vhostcontainer_servername_statement` = '1'";
+			 `vhostcontainer_servername_statement` = '1',
+			 `specialsettings` = 'DocumentRoot \"".$db->escape(dirname(dirname(__FILE__))) . "\"'";
 	$db->query($query);
 	$defaultip = $db->insert_id();
 
