@@ -14,7 +14,7 @@
  * @author     Froxlor Team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Language
- * @version    $Id: german.lng.php 291 2010-02-14 14:21:37Z d00p $
+ * @version    $Id: german.lng.php 655 2010-03-21 09:32:57Z d00p $
  */
 
 /**
@@ -84,4 +84,11 @@ $lng['install']['webserver'] = 'Webserver';
 $lng['install']['phpversion'] = 'Pr&uuml;fe PHP Version >= 5.2';
 $lng['install']['phpposix'] = 'Teste, ob die PHP Posix-Erweiterung installiert ist...';
 
+/*
+ * Added in Froxlor 0.9.4
+ */
+$lng['install']['click_here_to_refresh'] = 'Erneut pr&uuml;fen';
+$lng['install']['click_here_to_continue'] = 'Installation fortf&uuml;hren';
+$lng['install']['froxlor_succ_checks'] = 'Alle Vorraussetzungen sind erf&uuml;llt';
+
 ?>
