@@ -12,21 +12,21 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Language
- * @version    $Id: preconfig_0.9.inc.php 871 2010-05-03 11:48:28Z EleRas $
+ * @version    $Id: preconfig_0.9.inc.php 940 2010-05-17 08:26:55Z d00p $
  */
 
 /**
  * checks if the new-version has some updating to do
- * 
+ *
  * @param boolean $has_preconfig   pointer to check if any preconfig has to be output
  * @param string  $return          pointer to output string
  * @param string  $current_version current froxlor version
- * 
+ *
  * @return null
  */
 function parseAndOutputPreconfig(&$has_preconfig, &$return, $current_version)
 {
-	global $settings, $lng;
+	global $settings, $lng, $db;
 
 	if(versionInUpdate($current_version, '0.9.4-svn2'))
 	{
@@ -54,7 +54,7 @@ function parseAndOutputPreconfig(&$has_preconfig, &$return, $current_version)
 	if(versionInUpdate($current_version, '0.9.6-svn3'))
 	{
 		$has_preconfig = true;
-		$description = 'You now have the possibility to define default error-documents for your webserver which replace the default webserver error-messages.';  
+		$description = 'You now have the possibility to define default error-documents for your webserver which replace the default webserver error-messages.';
 		$question = '<strong>Do you want to enable default error-documents?:</strong>&nbsp;';
 		$question .= makeyesno('update_deferr_enable', '1', '0', '0').'<br /><br />';
 		if($settings['system']['webserver'] == 'apache2')
@@ -79,7 +79,7 @@ function parseAndOutputPreconfig(&$has_preconfig, &$return, $current_version)
 		$question .= $priorities.'</select>';
 		eval("\$return.=\"" . getTemplate("update/preconfigitem") . "\";");
 	}
-	
+
 	if(versionInUpdate($current_version, '0.9.6-svn5'))
 	{
 		$has_preconfig = true;
@@ -95,7 +95,7 @@ function parseAndOutputPreconfig(&$has_preconfig, &$return, $current_version)
 		$question .= $configs.'</select>';
 		eval("\$return.=\"" . getTemplate("update/preconfigitem") . "\";");
 	}
-	
+
 	if(versionInUpdate($current_version, '0.9.6-svn6'))
 	{
 		$has_preconfig = true;
@@ -107,4 +107,46 @@ function parseAndOutputPreconfig(&$has_preconfig, &$return, $current_version)
 		$question .= '</select>';
 		eval("\$return.=\"" . getTemplate("update/preconfigitem") . "\";");
 	}
+
+	if(versionInUpdate($current_version, '0.9.7-svn1'))
+	{
+		$has_preconfig = true;
+		$description = 'You can now choose whether customers can select the http-redirect code and which of them acts as default.';
+		$question = '<strong>Allow customer chosen redirects?:</strong>&nbsp;';
+		$question.= makeyesno('update_customredirect_enable', '1', '0', '1').'<br /><br />';
+		$question.= '<strong>Select default redirect code (default: empty):</strong>&nbsp;';
+		$question.= '<select name="update_customredirect_default">';
+		$redirects = makeoption('--- ('.$lng['redirect_desc']['rc_default'].')', 1, '1');
+		$redirects.= makeoption('301 ('.$lng['redirect_desc']['rc_movedperm'].')', 2, '1');
+		$redirects.= makeoption('302 ('.$lng['redirect_desc']['rc_found'].')', 3, '1');
+		$redirects.= makeoption('303 ('.$lng['redirect_desc']['rc_seeother'].')', 4, '1');
+		$redirects.= makeoption('307 ('.$lng['redirect_desc']['rc_tempred'].')', 5, '1');
+		$question .= $redirects.'</select>';
+		eval("\$return.=\"" . getTemplate("update/preconfigitem") . "\";");
+	}
+
+	if(versionInUpdate($current_version, '0.9.7-svn2'))
+	{
+		$result = $db->query("SELECT `domain` FROM " . TABLE_PANEL_DOMAINS . " WHERE `documentroot` LIKE '%:%' AND `documentroot` NOT LIKE 'http://%' AND `openbasedir_path` = '0' AND `openbasedir` = '1'");
+		$wrongOpenBasedirDomain = array();
+		while($row = $db->fetch_array($result))
+		{
+			$wrongOpenBasedirDomain[] = $row['domain'];
+		}
+
+		if(count($wrongOpenBasedirDomain) > 0)
+		{
+			$has_preconfig = true;
+			$description = 'Resetting the open_basedir to customer - root';
+			$question = '<strong>Due to a security - issue regarding open_basedir, Froxlor will set the open_basedir for the following domains to the customers root instead of the chosen documentroot:</strong><br />&nbsp;';
+			$question.= '<ul>';
+			$idna_convert = new idna_convert_wrapper();
+			foreach($wrongOpenBasedirDomain as $domain)
+			{
+				$question.= '<li>' . $idna_convert->decode($domain) . '</li>';
+			}
+			$question.= '</ul>';
+			eval("\$return.=\"" . getTemplate("update/preconfigitem") . "\";");
+		}
+	}
 }
