@@ -14,11 +14,16 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Install
- * @version    $Id: updatesql.php 138 2010-01-27 08:54:31Z Dessa $
+ * @version    $Id: updatesql.php 945 2010-05-17 09:10:02Z d00p $
  */
 
 $updatelog = FroxlorLogger::getInstanceOf(array('loginname' => 'updater'), $db, $settings);
 
+$updatelogfile = validateUpdateLogFile(makeCorrectFile(dirname(__FILE__).'/update.log'));
+$filelog = FileLogger::getInstanceOf(array('loginname' => 'updater'), $settings);
+$filelog->setLogFile($updatelogfile);
+$filelog->logAction(ADM_ACTION, LOG_WARNING, '-------------- START LOG --------------');
+
 /*
  * since froxlor, we have to check if there's still someone
  * out there using syscp and needs to upgrade
@@ -90,6 +95,8 @@ if(!isFroxlor())
 if(isFroxlor())
 {
 	include_once (makeCorrectFile(dirname(__FILE__).'/updates/froxlor/0.9/update_0.9.inc.php'));
+	$filelog->logAction(ADM_ACTION, LOG_WARNING, '--------------- END LOG ---------------');
+	unset($filelog);
 }
 
 ?>
