@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Functions
- * @version    $Id: function.validateUrl.php 841 2010-04-21 10:40:58Z d00p $
+ * @version    $Id: function.validateUrl.php 891 2010-05-04 10:31:25Z d00p $
  */
 
 /**
@@ -28,27 +28,21 @@
 
 function validateUrl($url)
 {
+	global $idna_convert;
+
 	if(strtolower(substr($url, 0, 7)) != "http://"
 	&& strtolower(substr($url, 0, 8)) != "https://")
 	{
 		$url = 'http://' . $url;
 	}
+	
+	// needs converting
+	$url = $idna_convert->encode($url);
 
-	if(version_compare("5.2.13", PHP_VERSION, "=")
-		|| version_compare("5.3.2", PHP_VERSION, "="))
+	$pattern = "/^https?:\/\/[a-zA-Z0-9\-\.]+\.[a-zA-Z]{2,3}(\/\S*)?$/i";
+	if(preg_match($pattern, $url))
 	{
-		$pattern = '/^https?:\/\/([a-z0-9]([a-z0-9\-]{0,61}[a-z0-9])?\.)+[a-z]{2,6}$/i';
-		if(preg_match($pattern, $url))
-		{
-			return true;
-		}
-	}
-	else
-	{
-		if(filter_var($url, FILTER_VALIDATE_URL, FILTER_FLAG_SCHEME_REQUIRED) !== false)
-		{
-			return true;
-		}
+		return true;
 	}
 
 	// not an fqdn
