@@ -14,7 +14,7 @@
  * @author     Froxlor Team <team@froxlor.org>
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Language
- * @version    $Id: english.lng.php 862 2010-05-01 12:37:05Z EleRas $
+ * @version    $Id: english.lng.php 940 2010-05-17 08:26:55Z d00p $
  */
 
 /**
@@ -1350,7 +1350,7 @@ $lng['serversettings']['stdsubdomainhost']['description'] = 'What hostname shoul
 // ADDED IN FROXLOR 0.9.4-svn1
 $lng['ftp']['account_edit'] = 'Edit ftp account';
 $lng['ftp']['editpassdescription'] = 'Set new password or leave blank for no change.';
-$lng['mysql']['sendinfomail'] = 'Send data via email to me';
+$lng['customer']['sendinfomail'] = 'Send data via email to me';
 $lng['customer']['mysql_add']['infomail_subject'] = '[Froxlor] New database created';
 $lng['customer']['mysql_add']['infomail_body']['pma'] = "\nYou can access your databases using phpMyAdmin via {URI}\n";
 $lng['customer']['mysql_add']['infomail_body']['main'] = "Hello {CUST_NAME},\n\nyou have just added a new database. Here is the entered information:\n\nDatabasename: {DB_NAME}\nPassword: {DB_PASS}\nDescription: {DB_DESC}\nDB-Hostname: {DB_SRV}\n{PMA_URI}\nYours sincerely, the Froxlor-Team";
@@ -1391,4 +1391,33 @@ $lng['serversettings']['ftpserver']['desc'] = 'If pureftpd is selected the .ftpq
 // CHANGED IN FROXLOR 0.9.6-svn6
 $lng['serversettings']['ftpprefix']['description'] = 'Which prefix should ftp accounts have?<br/><b>If you change this you also have to change the Quota SQL Query in your FTP Server config file in case you use it!</b> ';
 
+// ADDED IN FROXLOR 0.9.7-svn1
+$lng['customer']['ftp_add']['infomail_subject'] = '[Froxlor] New ftp-user created';
+$lng['customer']['ftp_add']['infomail_body']['main'] = "Hello {CUST_NAME},\n\nyou have just added a new ftp-user. Here is the entered information:\n\nUsername: {USR_NAME}\nPassword: {USR_PASS}\nPath: {USR_PATH}\n\nYours sincerely, the Froxlor-Team";
+$lng['domains']['redirectifpathisurl'] = 'Redirect code (default: empty)';
+$lng['domains']['redirectifpathisurlinfo'] = 'You only need to select one of these if you entered an URL as path';
+$lng['serversettings']['customredirect_enabled']['title'] = 'Allow customer redirects';
+$lng['serversettings']['customredirect_enabled']['description'] = 'Allow customers to choose the http-status code for redirects which will be used';
+$lng['serversettings']['customredirect_default']['title'] = 'Default redirect';
+$lng['serversettings']['customredirect_default']['description'] = 'Set the default redirect-code which should be used if the customer does not set it himself';
+
+// ADDED IN FROXLOR 0.9.7-svn2
+$lng['error']['pathmaynotcontaincolon'] = 'The path you have entered should not contain a colon (":"). Please enter a correct path value.';
+$lng['tasks']['aps_task_install'] = 'Installing one or more APS packages';
+$lng['tasks']['aps_task_remove'] = 'Removing one or more APS packages';
+$lng['tasks']['aps_task_reconfigure'] = 'Reconfigurating one or more APS packages';
+$lng['tasks']['aps_task_upgrade'] = 'Upgrading one or more APS packages';
+$lng['tasks']['aps_task_sysupdate'] = 'Updating all APS packages';
+$lng['tasks']['aps_task_sysdownload'] = 'Downloading new APS packages';
+
+// ADDED IN FROXLOR 0.9.7-svn3
+
+// these stay only in english.lng.php - they are the same
+// for all other languages and are used if not found there
+$lng['redirect_desc']['rc_default'] = 'default';
+$lng['redirect_desc']['rc_movedperm'] = 'moved permanently';
+$lng['redirect_desc']['rc_found'] = 'found';
+$lng['redirect_desc']['rc_seeother'] = 'see other';
+$lng['redirect_desc']['rc_tempred'] = 'temporary redirect';
+
 ?>
