@@ -16,7 +16,7 @@
  * @author     Froxlor Team <team@froxlor.org>
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Language
- * @version    $Id: french.lng.php 166 2010-01-30 13:07:25Z EleRas $
+ * @version    $Id: french.lng.php 759 2010-04-09 19:24:17Z EleRas $
  */
 
 /**
@@ -246,7 +246,6 @@ $lng['error']['destinationalreadyexistasmail'] = 'Le renvoi vers l\'adresse "%s"
 $lng['error']['destinationalreadyexist'] = 'Il existe dj une rexpdition vers l\'adresse "%s".';
 $lng['error']['destinationiswrong'] = 'L\'adresse "%s" contient des signes invalides ou est incomplte.';
 $lng['error']['domainname'] = $lng['domains']['domainname'];
-$lng['error']['youcantdeletechangemainadmin'] = 'Pour des raisons de scurit, il n\'est pas possible de supprimer ou modifier l\'administrateur principal.';
 $lng['error']['loginnameissystemaccount'] = 'Vous ne pouvez pas crer un compte identique au compte systme, veuillez ressayer avec un autre nom.';
 
 /**
@@ -255,7 +254,6 @@ $lng['error']['loginnameissystemaccount'] = 'Vous ne pouvez pas crer un compte i
 
 $lng['question']['question'] = 'Question de scurit';
 $lng['question']['admin_customer_reallydelete'] = 'Etes-vous sr de vouloir supprimer le compte "%s" ?<br />ATTENTION ! Toutes ses informations seront supprimes ! Une fois fait, il vous appartiendra de supprimer manuellement tous les dossiers du compte sur le systme de fichiers.';
-$lng['question']['admin_domain_reallyenablemailsystemhostname'] = 'Etes-vous sr de vouloir activ le serveur de nom en tant que serveur de mails ?';
 $lng['question']['admin_domain_reallydelete'] = 'Etes-vous sr de vouloir supprimer le domaine "%s" ?';
 $lng['question']['admin_domain_reallydisablesecuritysetting'] = 'Etes-vous sr de vouloir dsactiver les modes de scurit suivants : OpenBasedir et / o SafeMode ?';
 $lng['question']['admin_admin_reallydelete'] = 'Etes-vous sr de vouloir supprimer l\'administrateur "%s" ?<br />Tous ses comptes seront affects  l\'administrateur principal.';
@@ -359,8 +357,6 @@ $lng['serversettings']['hostname']['title'] = 'Nom d\'hte';
 $lng['serversettings']['hostname']['description'] = 'Quel est le nom d\'hte (hostname) du serveur ?';
 $lng['serversettings']['apachereload_command']['title'] = 'Commande de rechargement d\'Apache';
 $lng['serversettings']['apachereload_command']['description'] = 'Quelle est la commande pour recharger / redmarrer Apache ?';
-$lng['serversettings']['apacheconf_filename']['title'] = 'Nom du fichier de configuration Apache';
-$lng['serversettings']['apacheconf_filename']['description'] = 'Dans quel fichier souhaitez-vous enregistrer la configuration Apache ?';
 $lng['serversettings']['bindconf_directory']['title'] = 'Emplacement du dossier de configuration de Bind / Named';
 $lng['serversettings']['bindconf_directory']['description'] = 'O doit tre stock la configuration de Bind / Named ?';
 $lng['serversettings']['bindreload_command']['title'] = 'Commande de rechargement de Bind / Named';
@@ -403,7 +399,6 @@ $lng['mysql']['description'] = 'Ici, vous pouvez ajouter et effacer des bases de
  * ADDED BETWEEN 1.2.12 and 1.2.13
  */
 
-$lng['admin']['cronlastrun'] = 'Dernire tche "cron"';
 $lng['serversettings']['paging']['title'] = 'Nombre de rsultats par page';
 $lng['serversettings']['paging']['description'] = 'Nombre de rsultats par page ? (0 = Dsactive la pagination)';
 $lng['error']['ipstillhasdomains'] = 'La combinaison IP / port est encore utilise, veuillez rassigner le ou les domaines existant(s) avec cette adresse IP / port concern(s)  une autre combinaison IP / port avant de supprimer celle-ci.';
@@ -452,7 +447,6 @@ $lng['error']['phpmyadminiswrong'] = 'Le lien pour phpMyAdmin n\'est pas valide.
 $lng['error']['webmailiswrong'] = 'Le lien pour le WebMail n\'est pas valide.';
 $lng['error']['webftpiswrong'] = 'Le lien pour le WebFTP n\'est pas valide.';
 $lng['domains']['hasaliasdomains'] = 'Le domaine possde un ou des alias.';
-$lng['domains']['istopleveldomain'] = 'Est le nom de domaine principal';
 $lng['serversettings']['defaultip']['title'] = 'IP / Port par dfaut';
 $lng['serversettings']['defaultip']['description'] = 'Quel est l\'IP / Port par dfaut ?';
 $lng['domains']['statstics'] = 'Frquentation';
@@ -546,7 +540,6 @@ $lng['admin']['configfiles']['etc'] = 'Autres (Systme)';
 $lng['admin']['configfiles']['choosedistribution'] = '-- Choisissez une distribution --';
 $lng['admin']['configfiles']['chooseservice'] = '-- Choisissez un service --';
 $lng['admin']['configfiles']['choosedaemon'] = '-- Choisissez un dmon --';
-$lng['admin']['trafficlastrun'] = 'Dernier calcul du trafic';
 
 // ADDED IN 1.2.16-svn10
 
@@ -811,10 +804,6 @@ $lng['cronjobs']['notyetrun'] = 'Pas encore lanc';
 $lng['install']['servername_should_be_fqdn'] = 'Le nom du serveur doit tre un nom FQDN, pas une adresse IP';
 $lng['serversettings']['default_vhostconf']['title'] = 'Paramtres par dfaut pour les vHosts';
 $lng['emails']['quota'] = 'Quota';
-$lng['emails']['quota_type']['byte'] = 'octet(s)';
-$lng['emails']['quota_type']['kilobyte'] = 'Ko';
-$lng['emails']['quota_type']['megabyte'] = 'Mo';
-$lng['emails']['quota_type']['gigabyte'] = 'Go';
 $lng['emails']['noquota'] = 'Pas de quota';
 $lng['emails']['updatequota'] = 'Mise  jour';
 $lng['serversettings']['mail_quota']['title'] = 'Quota de la bote aux lettres';
@@ -859,8 +848,6 @@ $lng['error']['cannotuseawstatsandwebalizeratonetime'] = 'Vous ne pouvez pas act
 $lng['serversettings']['webalizer_enabled'] = 'Activer les statistiques Webalizer';
 $lng['serversettings']['awstats_enabled'] = 'Activer les statistiques AWStats';
 $lng['admin']['awstatssettings'] = 'Paramtres Awstats';
-$lng['serversettings']['awstats_domain_file']['title'] = 'Dossier domaines pour AWStats';
-$lng['serversettings']['awstats_model_file']['title'] = 'Fichier modle pour AWStats';
 
 // ADDED IN 1.2.19-svn16
 
