@@ -17,7 +17,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Cron
- * @version    $Id: cron_autoresponder.php 518 2010-03-03 08:51:13Z d00p $
+ * @version    $Id: cron_autoresponder.php 729 2010-04-06 19:28:39Z d00p $
  * @todo	   skip mail parsing after x bytes for large mails
  */
 
@@ -80,7 +80,7 @@ if($db->num_rows($result) > 0)
 		
 		$path = $row['homedir'] . $row['maildir'] . "new/";
 		
-		if(!is_dir($paht) || !is_readable($path))
+		if(!is_dir($path) || !is_readable($path))
 		{
 			$cronlog->logAction(CRON_ACTION, LOG_WARNING, "Error accessing maildir: " . $path);
 			continue;
