@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Cron
- * @version    $Id: cron_tasks.inc.http.10.apache.php 848 2010-04-28 07:04:01Z d00p $
+ * @version    $Id: cron_tasks.inc.http.10.apache.php 930 2010-05-12 06:52:11Z d00p $
  */
 
 if(@php_sapi_name() != 'cli'
@@ -270,23 +270,17 @@ class apache
 
 			if($domain['openbasedir'] == '1')
 			{
-				if($this->settings['system']['phpappendopenbasedir'] != '')
+				if($domain['openbasedir_path'] == '1' || strstr($domain['documentroot'], ":") !== false)
 				{
-					$_phpappendopenbasedir = ':' . $this->settings['system']['phpappendopenbasedir'];
+					$_phpappendopenbasedir = appendOpenBasedirPath($domain['customerroot'], true);
 				}
 				else
 				{
-					$_phpappendopenbasedir = '';
-				}
-
-				if($domain['openbasedir_path'] == '1')
-				{
-					$php_options_text.= '  php_admin_value open_basedir "' . $domain['customerroot'] . $_phpappendopenbasedir . "\"\n";
-				}
-				else
-				{
-					$php_options_text.= '  php_admin_value open_basedir "' . $domain['documentroot'] . $_phpappendopenbasedir . "\"\n";
+					$_phpappendopenbasedir = appendOpenBasedirPath($domain['documentroot'], true);
 				}
+				$_phpappendopenbasedir .= appendOpenBasedirPath($this->settings['system']['phpappendopenbasedir']);
+				
+				$php_options_text.= '  php_admin_value open_basedir "' . $_phpappendopenbasedir . '"'."\n";
 			}
 
 			if($domain['safemode'] == '0')
@@ -622,7 +616,8 @@ class apache
 
 		if(preg_match('/^https?\:\/\//', $domain['documentroot']))
 		{
-			$vhost_content.= '  Redirect 301 / ' . $this->idnaConvert->encode($domain['documentroot']) . "\n";
+			$code = getDomainRedirectCode($domain['id']);
+			$vhost_content.= '  Redirect '.$code.' / ' . $this->idnaConvert->encode($domain['documentroot']) . "\n";
 		}
 		else
 		{
