@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Cron
- * @version    $Id: cron_tasks.inc.http.15.apache_fcgid.php 115 2010-01-25 13:19:45Z EleRas $
+ * @version    $Id: cron_tasks.inc.http.15.apache_fcgid.php 930 2010-05-12 06:52:11Z d00p $
  */
 
 if(@php_sapi_name() != 'cli'
@@ -166,22 +166,31 @@ class apache_fcgid extends apache
 			if($domain['openbasedir'] == '1')
 			{
 				$openbasedirc = '';
-				if($domain['openbasedir_path'] == '0')
+				$_phpappendopenbasedir = appendOpenBasedirPath($this->settings['system']['mod_fcgid_peardir']);
+				$_phpappendopenbasedir .= appendOpenBasedirPath($this->settings['system']['phpappendopenbasedir']);
+				
+				if($domain['openbasedir_path'] == '0' && strstr($domain['documentroot'], ":") === false)
 				{
-					$openbasedir = $domain['documentroot'] . ':' . $tmpdir . ':' . $this->settings['system']['mod_fcgid_peardir'] . ':' . $this->settings['system']['phpappendopenbasedir'];
+					$openbasedir = appendOpenBasedirPath($domain['documentroot'], true);
 				}
 				else
 				{
-					$openbasedir = $domain['customerroot'] . ':' . $tmpdir . ':' . $this->settings['system']['mod_fcgid_peardir'] . ':' . $this->settings['system']['phpappendopenbasedir'];
+					$openbasedir = appendOpenBasedirPath($domain['customerroot'], true);
 				}
 
+				$openbasedir .= appendOpenBasedirPath($tmpdir);
+				$openbasedir .= $_phpappendopenbasedir;
+
 				$openbasedir = explode(':', $openbasedir);
+				$clean_openbasedir = array();
 				foreach($openbasedir as $number => $path)
 				{
-					$openbasedir[$number] = makeCorrectDir($path);
+					if(trim($path) != '/')
+					{
+						$clean_openbasedir[] = makeCorrectDir($path);
+					}
 				}
-
-				$openbasedir = implode(':', $openbasedir);
+				$openbasedir = implode(':', $clean_openbasedir);
 			}
 			else
 			{
