@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Cron
- * @version    $Id: cron_tasks.inc.http.20.lighttpd.php 790 2010-04-14 06:42:14Z d00p $
+ * @version    $Id: cron_tasks.inc.http.20.lighttpd.php 848 2010-04-28 07:04:01Z d00p $
  */
 
 /*
@@ -151,6 +151,30 @@ class lighttpd
 			
 			$this->lighttpd_data[$vhost_filename].= '}' . "\n";
 		}
+
+		/**
+		 * bug #unknown-yet
+		 */
+		$this->_createStandardErrorHandler();
+	}
+
+	/**
+	 * define a default server.error-handler-404-statement, bug #unknown-yet
+	 */
+	private function _createStandardErrorHandler()
+	{
+		if($this->settings['defaultwebsrverrhandler']['enabled'] == '1'
+			&& $this->settings['defaultwebsrverrhandler']['err404'] != ''
+		) {
+			$vhosts_filename = makeCorrectFile($this->settings['system']['apacheconf_vhost'] . '/05_froxlor_default_errorhandler.conf');
+
+			if(!isset($this->lighttpd_data[$vhost_filename]))
+			{
+				$this->lighttpd_data[$vhost_filename] = '';
+			}
+
+			$this->lighttpd_data[$vhost_filename] = 'server.error-handler-404 = "'.$this->settings['defaultwebsrverrhandler']['err404'].'"';
+		}
 	}
 
 	protected function create_htaccess($domain)
@@ -807,9 +831,7 @@ class lighttpd
 		fwrite($this->debugHandler, '  lighttpd::wipeOutOldConfigs: cleaning ' . $this->settings['system']['apacheconf_vhost'] . "\n");
 		$this->logger->logAction(CRON_ACTION, LOG_INFO, "cleaning " . $this->settings['system']['apacheconf_vhost']);
 
-		if(isConfigDir($this->settings['system']['apacheconf_vhost'])
-		&& file_exists($this->settings['system']['apacheconf_vhost'])
-		&& is_dir($this->settings['system']['apacheconf_vhost']))
+		if(isConfigDir($this->settings['system']['apacheconf_vhost'], true))
 		{
 			$vhost_file_dirhandle = opendir($this->settings['system']['apacheconf_vhost']);
 
